Skip to main contentCrate ic_analytics_sdk
Source - AnalyticsClient
- HistogramPage
- A page of histogram data points returned by
get_histogram_page. - LogPage
- A page of log entries returned by
get_log_page. - Metric
- An incoming metric record.
- TransformerInfo
- Metadata returned when listing or fetching a transformer definition.
- MetricValue
- The value carried by an incoming metric record.
Determines how the metric is stored and aggregated.
- StoredMetric
- The aggregated metric as stored in the canister, keyed by
key. - TransformerOutput
- The result produced by running a transformer script.